@@ -7,16 +7,16 @@ _Func = TypeVar("_Func", bound=Callable[..., Any])
 
 def timer(func: _Func) -> _Func:
     def wrapper(*args: Any, **kwargs: Dict[Any, Any]) -> Any:
-        startTime = time.perf_counter()
+        start_time = time.perf_counter()
 
         retval = func(*args, **kwargs)
 
-        endTime = time.perf_counter()
+        end_time = time.perf_counter()
 
-        elapsedMs = (endTime - startTime) * 1000
+        elapsed_ms = (end_time - start_time) * 1000
 
         logging.getLogger(__name__).debug(
-            f"[{func.__qualname__}] - duration: {elapsedMs:.2f}ms"
+            f"[{func.__qualname__}] - duration: {elapsed_ms:.2f}ms"
         )
 
         return retval
