@@ -8,17 +8,17 @@ import pandas as pd
 from tqdm.notebook import tqdm
 
 from the_census._api.interface import ICensusApiFetchService
-from the_census._dataTransformation.interface import ICensusDataTransformer
+from the_census._data_transformation.interface import ICensusDataTransformer
 from the_census._persistence.interface import ICache
 from the_census._utils.log.factory import ILoggerFactory
 from the_census._utils.timer import timer
-from the_census._utils.unique import getUnique
+from the_census._utils.unique import get_unique
 from the_census._variables.models import Group, GroupCode, GroupVariable
 from the_census._variables.repository.interface import IVariableRepository
 from the_census._variables.repository.models import GroupSet, VariableSet
 
 GROUPS_FILE = "groups.csv"
-SUPPORTED_GEOS_FILE = "supportedGeographies.csv"
+SUPPORTED_GEOS_FILE = "supported_geographies.csv"
 
 VARIABLES_DIR = "variables"
 
@@ -35,31 +35,31 @@ class VariableRepository(IVariableRepository[pd.DataFrame]):
         cache: ICache[pd.DataFrame],
         transformer: ICensusDataTransformer[pd.DataFrame],
         api: ICensusApiFetchService,
-        loggerFactory: ILoggerFactory,
+        logger_factory: ILoggerFactory,
     ):
         self._cache = cache
         self._api = api
         self._transformer = transformer
-        self._logger = loggerFactory.getLogger(__name__)
+        self._logger = logger_factory.getLogger(__name__)
 
         # these are inherited from the base class
         self._variables = VariableSet()
         self._groups = GroupSet()
 
-        self.__populateRepository()
+        self.__populate_repository()
 
     @timer
-    def getGroups(self) -> pd.DataFrame:
-        return self.__getGroups()
+    def get_groups(self) -> pd.DataFrame:
+        return self.__get_groups()
 
     @cache
-    def __getGroups(self) -> pd.DataFrame:
+    def __get_groups(self) -> pd.DataFrame:
         df = self._cache.get(GROUPS_FILE)
         if df is None:
             df = pd.DataFrame()
 
         if df.empty:
-            res = self._api.groupData()
+            res = self._api.group_data()
 
             if len(res) == 0:
                 return pd.DataFrame()
@@ -68,18 +68,18 @@ class VariableRepository(IVariableRepository[pd.DataFrame]):
 
             self._cache.put(GROUPS_FILE, df)
 
-        groups = [Group.fromDfRecord(rec) for rec in df.to_dict("records")]
+        groups = [Group.from_df_record(rec) for rec in df.to_dict("records")]
         self._groups.add(*groups)
 
-        return df.drop(columns=["cleanedName"])  # type: ignore
+        return df.drop(columns=["cleaned_name"])  # type: ignore
 
     @timer
-    def getVariablesByGroup(self, *groups: GroupCode) -> pd.DataFrame:
-        return self.__getVariablesByGroup(tuple(getUnique(groups)))
+    def get_variables_by_group(self, *groups: GroupCode) -> pd.DataFrame:
+        return self.__get_variables_by_group(tuple(get_unique(groups)))
 
     @cache
-    def __getVariablesByGroup(self, groups: Tuple[GroupCode, ...]) -> pd.DataFrame:
-        allVars = pd.DataFrame()
+    def __get_variables_by_group(self, groups: Tuple[GroupCode, ...]) -> pd.DataFrame:
+        all_vars = pd.DataFrame()
 
         for group in tqdm(groups):  # type: ignore
             resource = f"{VARIABLES_DIR}/{group}.csv"
@@ -89,12 +89,12 @@ class VariableRepository(IVariableRepository[pd.DataFrame]):
                 df = pd.DataFrame()
 
             if not df.empty:
-                if allVars.empty:
-                    allVars = df
+                if all_vars.empty:
+                    all_vars = df
                 else:
-                    allVars = allVars.append(df, ignore_index=True)  # type: ignore
+                    all_vars = all_vars.append(df, ignore_index=True)  # type: ignore
             else:
-                res = self._api.variablesForGroup(cast(GroupCode, group))
+                res = self._api.variables_for_group(cast(GroupCode, group))
 
                 if len(res) == 0:
                     continue
@@ -103,76 +103,76 @@ class VariableRepository(IVariableRepository[pd.DataFrame]):
 
                 self._cache.put(resource, df)
 
-                if allVars.empty:
-                    allVars = df
+                if all_vars.empty:
+                    all_vars = df
                 else:
-                    allVars = allVars.append(df, ignore_index=True)
+                    all_vars = all_vars.append(df, ignore_index=True)
 
-        if allVars.empty:
+        if all_vars.empty:
             return pd.DataFrame()
 
-        for record in allVars.to_dict("records"):
-            var = GroupVariable.fromDfRecord(record)
+        for record in all_vars.to_dict("records"):
+            var = GroupVariable.from_df_record(record)
             self._variables.add(var)
 
-        return allVars.drop(columns=["cleanedName"])  # type: ignore
+        return all_vars.drop(columns=["cleaned_name"])  # type: ignore
 
     @timer
-    def getAllVariables(self) -> pd.DataFrame:
-        return self.__getAllVariables()
+    def get_all_variables(self) -> pd.DataFrame:
+        return self.__get_all_variables()
 
     @cache
-    def __getAllVariables(self) -> pd.DataFrame:
+    def __get_all_variables(self) -> pd.DataFrame:
         self._logger.info("This is a costly operation, and may take time")
 
-        allVariables = self._api.allVariables()
+        all_variables = self._api.all_variables()
 
-        if len(allVariables) == 0:
+        if len(all_variables) == 0:
             return pd.DataFrame()
 
-        df = self._transformer.variables(allVariables)
+        df = self._transformer.variables(all_variables)
 
-        for groupCode, variables in df.groupby(["groupCode"]):  # type: ignore
+        for GroupCode, variables in df.groupby(["group_code"]):  # type: ignore
             varDf = cast(pd.DataFrame, variables)
 
-            if not self._cache.put(f"{VARIABLES_DIR}/{groupCode}.csv", varDf):
+            if not self._cache.put(f"{VARIABLES_DIR}/{GroupCode}.csv", varDf):
                 # we don't need to update `self._variables` in this case
                 continue
 
             variables = [
-                GroupVariable.fromDfRecord(record)
+                GroupVariable.from_df_record(record)
                 for record in varDf.to_dict("records")
             ]
             self._variables.add(*variables)
 
-        return df.drop(columns=["cleanedName"])  # type: ignore
+        return df.drop(columns=["cleaned_name"])  # type: ignore
 
-    def __populateRepository(self) -> None:
+    def __populate_repository(self) -> None:
         self._logger.debug("populating repository")
 
-        groupsDf = self._cache.get(GROUPS_FILE)
+        groups_df = self._cache.get(GROUPS_FILE)
 
-        if groupsDf is not None:
+        if groups_df is not None:
             groups = [
-                Group.fromDfRecord(record) for record in groupsDf.to_dict("records")
+                Group.from_df_record(record) for record in groups_df.to_dict("records")
             ]
             self._logger.debug(f"adding groups {[group.code for group in groups]}")
             self._groups.add(*groups)
 
-        variablesPath = f"{self._cache.cachePath}/{VARIABLES_DIR}"
+        variables_path = f"{self._cache.cache_path}/{VARIABLES_DIR}"
 
-        if not Path(variablesPath).exists():
+        if not Path(variables_path).exists():
             self._logger.debug("no variables")
             return
 
-        for file in os.listdir(variablesPath):
-            cacheRes = self._cache.get(f"{VARIABLES_DIR}/{file}")
-            variableDf = cacheRes if cacheRes is not None else pd.DataFrame()
+        for file in os.listdir(variables_path):
+            cache_res = self._cache.get(f"{VARIABLES_DIR}/{file}")
+            variable_df = cache_res if cache_res is not None else pd.DataFrame()
 
             self._logger.debug(f"adding variables from {file}")
 
             variables = [
-                GroupVariable.fromDfRecord(record)
-                for record in variableDf.to_dict("records")
+                GroupVariable.from_df_record(record)
+                for record in variable_df.to_dict("records")
             ]
             self._variables.add(*variables)
